@@ -171,8 +171,9 @@ type curlHTTPVersion =
   | HTTP_VERSION_NONE (** libcurl will make the best choice *)
   | HTTP_VERSION_1_0 (** please use HTTP 1.0 *)
   | HTTP_VERSION_1_1 (** please use HTTP 1.1 *)
-  | HTTP_VERSION_2 (** please use HTTP 2 *)
-  | HTTP_VERSION_2TLS (** use version 2 for HTTPS, version 1.1 for HTTP *)
+  | HTTP_VERSION_2 (** please use HTTP 2 (requires libcurl >= 7.33.0, otherwise will fallback to libcurl choice) *)
+  | HTTP_VERSION_2TLS (** use version 2 for HTTPS, version 1.1 for HTTP (requires libcurl >= 7.47.0) *)
+  | HTTP_VERSION_2_PRIOR_KNOWLEDGE (** Issue non-TLS HTTP requests using HTTP/2 without HTTP/1 (requires libcurl >= 7.49.0) *)
 
 type curlDebugType =
   | DEBUGTYPE_TEXT
@@ -253,6 +254,39 @@ type curlProxyType =
   | CURLPROXY_SOCKS4A (** since libcurl 7.18.0 *)
   | CURLPROXY_SOCKS5_HOSTNAME (** since libcurl 7.18.0 *)
 
+type curlMIMEPartData =
+  | CURLMIME_DATA of string
+  | CURLMIME_FILEDATA of string
+
+type curlMIMEEncoding =
+  | CURLMIME_8BIT
+  | CURLMIME_BINARY
+  | CURLMIME_7BIT
+  | CURLMIME_QUOTEDPRINTABLE
+  | CURLMIME_BASE64
+  | CURLMIME_NONE
+
+type curlMIMEPart =
+  {
+    encoding: curlMIMEEncoding;
+    headers: string list;
+    subparts: curlMIMEPart list;
+    data: curlMIMEPartData;
+  }
+
+type curlKHMatch =
+  | CURLKHMATCH_OK
+  | CURLKHMATCH_MISMATCH of string
+  (** Argument consists of the base64-encoded public key of the remote host as
+      as found in the "known hosts" file **)
+  | CURLKHMATCH_MISSING
+
+type curlKHStat =
+  | CURLKHSTAT_FINE_ADD_TO_FILE
+  | CURLKHSTAT_FINE
+  | CURLKHSTAT_REJECT
+  | CURLKHSTAT_DEFER
+
 (** Protocols to enable (via CURLOPT_PROTOCOLS and CURLOPT_REDIR_PROTOCOLS) *)
 type curlProto =
 | CURLPROTO_ALL (** enable everything *)
@@ -432,6 +466,12 @@ type curlOption =
   | CURLOPT_LOGIN_OPTIONS of string
   | CURLOPT_CONNECT_TO of string list
   | CURLOPT_POSTREDIR of curlPostRedir list
+  | CURLOPT_MIMEPOST of curlMIMEPart list (* @since libcurl 7.56.0 *)
+  | CURLOPT_SSHKNOWNHOSTS of string
+  | CURLOPT_SSHKEYFUNCTION of (curlKHMatch -> string -> curlKHStat)
+  (** The second argument to the passed function consists of the raw bytes of
+      the public key sent by the remote host. If the function raises an
+      exception the key will be rejected, and the connection will fail.**)
 
 type initOption =
   | CURLINIT_GLOBALALL
@@ -509,11 +549,6 @@ val global_cleanup : unit -> unit
 val init : unit -> t
 val reset : t -> unit
 (** Reset [t] to the default state *)
-val duphandle : t -> t
-(** Create the new handle, copying all the options from the supplied [t].
-Note that it will also copy [set_writefunction] options and alike, as such both
-handles (original and new one) will be referencing the same closures, potentially
-sharing some state, which may lead to surprising results. *)
 val setopt : t -> curlOption -> unit
 (** @raise NotImplemented for not implemented option *)
 val perform : t -> unit
@@ -524,6 +559,9 @@ val unescape : string -> string
 val getdate : string -> float -> float
 val version : unit -> string
 val strerror : curlCode -> string
+val int_of_curlCode : curlCode -> int
+val curlCode_of_int : int -> curlCode option
+(** same as [int_of_curlCode] *)
 val errno : curlCode -> int
 val version_info : unit -> version_info
 val pause : t -> pauseOption list -> unit
@@ -688,6 +726,11 @@ val set_connect_to : t -> string list -> unit
 (** @since 0.8.0 *)
 val set_postredir : t -> curlPostRedir list -> unit
 (** @since 0.8.1 *)
+val set_mimepost : t -> curlMIMEPart list -> unit
+(** @since 0.8.2 *)
+
+val set_sshknownhosts : t -> string -> unit
+val set_sshkeyfunction : t -> (curlKHMatch -> string -> curlKHStat) -> unit
 
 (** {2 Get transfer properties} *)
 
@@ -739,7 +782,6 @@ class handle :
     val conn : t
     method handle : t
     method cleanup : unit
-    method duphandle : 'a
     method perform : unit
 
     method set_writefunction : (string -> int) -> unit
@@ -874,6 +916,9 @@ class handle :
     method set_proxytype : curlProxyType -> unit
     method set_resolve : (string * int * string) list -> (string * int) list -> unit
     method set_dns_servers : string list -> unit
+    method set_mimepost : curlMIMEPart list -> unit
+    method set_sshknownhosts : string -> unit
+    method set_sshkeyfunction : (curlKHMatch -> string -> curlKHStat) -> unit
 
     method get_effectiveurl : string
     method get_redirecturl : string
